@@ -4,7 +4,7 @@ package Chart::GGPlot;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_01'; # TRIAL VERSION
+our $VERSION = '0.0000_02'; # TRIAL VERSION
 
 use Data::Munge qw(elem);
 use Data::Frame::Types qw(DataFrame);
@@ -138,7 +138,7 @@ Chart::GGPlot - ggplot2 port in Perl
 
 =head1 VERSION
 
-version 0.0000_01
+version 0.0000_02
 
 =head1 STATUS
 
@@ -176,6 +176,7 @@ Example exported image files:
     ggplot(:$data, :$mapping, %rest)
 
 This is same as C<Chart::GGPlot::Plot-E<gt>new(...)>.
+See L<Chart::GGPlot::Plot> for details.
 
 =head2 qplot
 
@@ -195,6 +196,8 @@ A positive integer would enable debug messages.
 
 L<ggplot|https://en.wikipedia.org/wiki/Ggplot>
 
+L<Chart::GGPlot::Plot>
+
 L<Alt::Data::Frame::ButMore>
 
 =head1 AUTHOR
@@ -203,7 +206,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Stephan Loyd.
+This software is copyright (c) 2019 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
