@@ -5,7 +5,7 @@ package Chart::GGPlot::Params;
 use Chart::GGPlot::Setup;
 use Function::Parameters qw(classmethod);
 
-our $VERSION = '0.0000_01'; # TRIAL VERSION
+our $VERSION = '0.0000_02'; # TRIAL VERSION
 
 use List::AllUtils qw(pairgrep pairmap);
 use Storable qw(dclone);
@@ -30,6 +30,9 @@ sub _hash { $_[0]->{_hash} }
 classmethod transform_key ($key) { $key }
 
 
+method length () { scalar(@{$self->keys}); }
+
+
 method exists ($key) { exists $self->_hash->{ $self->transform_key($key) }; }
 
 
@@ -42,7 +45,7 @@ method values () {
 }
 
 
-method isempty () { @{ $self->keys } == 0; }
+method isempty () { $self->length == 0; }
 
 
 method delete ($key) {
@@ -118,10 +121,12 @@ method rename ($href_or_coderef) {
 method as_hashref () { $self->_hash; }
 
 
-method clone () {
+method copy () {
     return dclone($self);
 }
 
+*clone = \&copy;
+
 1;
 
 __END__
@@ -136,7 +141,7 @@ Chart::GGPlot::Params - Collection of key-value pairs used in Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0000_01
+version 0.0000_02
 
 =head1 DESCRIPTION
 
@@ -147,50 +152,86 @@ the C<transform_key> classmethod.
 
 =head1 CLASS METHODS
 
-=head2 transform_key($key)
+=head2 transform_key
+
+    transform_key($key)
 
 Derived classes can override this classmethod to have their own way
 of renaming the keys.
 
 =head1 METHODS
 
-=head2 exists($key)
+=head2 length
+
+    length()
+
+Returns the count of keys.
+
+=head2 exists
+
+    exists($key)
 
 Tests if a key exists.
 
-=head2 keys()
+=head2 keys
+
+    keys()
 
 Return an array ref of keys. 
 
-=head2 names()
+=head2 names
+
+    names()
 
 This is an alias of the C<keys()> method.
 
-=head2 values()
+=head2 values
+
+    values()
 
 Return an array ref of values. 
 
-=head2 isempty()
+=head2 isempty
 
-=head2 delete($key)
+    isempty()
 
-=head2 set($key, $value)
+Return a boolean value if length is 0.
+
+=head2 delete
+
+    delete($key)
+
+=head2 set
+
+    set($key, $value)
 
 Associate a value with a key and return the value.
 
-=head2 at($key)
+=head2 at
+
+    at($key)
 
 Get associated value of the given key.
 
-=head2 flatten()
+=head2 flatten
 
-=head2 hslice($keys)
+    flatten()
 
-=head2 slice($keys)
+Returns an array.
+
+=head2 hslice
+
+    hslice($keys)
+
+=head2 slice
+
+    slice($keys)
 
 This is an alias of C<hslice>.
 
-=head2 kv()
+=head2 kv
+
+    kv()
 
 Return a list of a value with a key and return the value.
 
@@ -204,20 +245,36 @@ would be skipped.
 
     my $merged = $params->merge($other);
 
-=head2 defaults($other)
+=head2 defaults
+
+    defaults($other)
 
 Using data from C<$other> as defaults.
 If C<$other> is C<undef>, returns a clone of C<$self>.
 
-=head2 rename($href_or_coderef)
+=head2 rename
 
-    my $p2 = $p1->rename( { $from_key => $to_key, ... } );
+    rename($href_or_coderef)
 
 Returns a new object.
 
-=head2 as_hashref()
+    my $p2 = $p1->rename( { $from_key => $to_key, ... } );
 
-=head2 clone()
+=head2 as_hashref
+
+    as_hashref()
+
+Returns a hashref.
+
+=head2 copy
+
+    copy()
+
+=head2 clone
+
+    clone()
+
+This is same as the C<copy()> method.
 
 =head1 SEE ALSO
 
@@ -229,7 +286,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Stephan Loyd.
+This software is copyright (c) 2019 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
