@@ -5,9 +5,10 @@ package Chart::GGPlot::Plot;
 use Chart::GGPlot::Class;
 use namespace::autoclean;
 
-our $VERSION = '0.0000_01'; # TRIAL VERSION
+our $VERSION = '0.0000_02'; # TRIAL VERSION
 
 use Autoload::AUTOCAN;
+use Data::Frame::Types qw(DataFrame);
 use List::AllUtils qw(pairgrep pairmap firstres);
 use Module::Load;
 use Package::Stash;
@@ -23,30 +24,57 @@ use Chart::GGPlot::Params;
 use Chart::GGPlot::ScalesList;
 use Chart::GGPlot::Types qw(:all);
 
+# We use Perl's autoloading feature, to get this class to support as its
+# member methods all exported functions of C<:ggplot> tag from several
+# other namespaces:
+#
+# Chart::GGPlot::Coord::Functions
+# Chart::GGPlot::Facet::Functions
+# Chart::GGPlot::Geom::Functions
+# Chart::GGPlot::Guide::Functions
+# Chart::GGPlot::Labels::Functions
+# Chart::GGPlot::Scale::Functions
+# Chart::GGPlot::Limits
+# Chart::GGPlot::Theme::Defaults
+#
+# For example, when you do
+#
+#    $plot->geom_point(...)
+#
+# It internally does something like,
+#
+#    my $layer = Chart::GGPlot::Geom::Functions::geom_point(...);
+#    $plot->add_layer($layer);
+#
+# Depend on the return type of the function it would call one of the class's
+# add/set methods. In this case of geom_point() we get a layer object so
+# add_layer() is called.
+
+my @function_namespaces = qw(
+  Chart::GGPlot::Coord::Functions
+  Chart::GGPlot::Facet::Functions
+  Chart::GGPlot::Geom::Functions
+  Chart::GGPlot::Guide::Functions
+  Chart::GGPlot::Labels::Functions
+  Chart::GGPlot::Scale::Functions
+  Chart::GGPlot::Limits
+  Chart::GGPlot::Theme::Defaults
+);
+
+for (@function_namespaces) {
+    load $_;
+}
+
 method AUTOCAN ($method) {
     state $known_methods;   # mapping method name to coderef
     unless ($known_methods) {
-        my @namespaces = qw(
-          Chart::GGPlot::Coord::Functions
-          Chart::GGPlot::Facet::Functions
-          Chart::GGPlot::Geom::Functions
-          Chart::GGPlot::Guide::Functions
-          Chart::GGPlot::Labels::Functions
-          Chart::GGPlot::Scale::Functions
-          Chart::GGPlot::Limits
-          Chart::GGPlot::Theme::Defaults
-        );
-
-        for (@namespaces) {
-            load $_;
-        }
         $known_methods = {
             map {
                 my $ns = $_;
                 no strict 'refs';
                 my @funcs = @{ ${"${ns}::EXPORT_TAGS"}{ggplot} };
                 map { $_ => \&{"${ns}::$_"}; } @funcs;
-            } @namespaces
+            } @function_namespaces
         };
     }
     my $f = $known_methods->{$method};
@@ -81,23 +109,36 @@ method AUTOCAN ($method) {
                 return $self;
             }
         }
-        die "Invalid data $x got from method $method";
+        die "Unsupported data type: $x got from method $method";
     };
 }
 
+
 my $DEFAULT_BACKEND = 'Plotly';
 
 has backend => (
     is      => 'ro',
     isa     => ConsumerOf ['Chart::GGPlot::Backend'],
-    default => sub {
+    builder => sub {
         my $backend_class = "Chart::GGPlot::Backend::$DEFAULT_BACKEND";
         load $backend_class;
         return $backend_class->new();
     },
 );
 
-has data   => ( is => 'ro' );
+
+has data   => (
+    is => 'ro', 
+    isa => DataFrame,
+);
+
+
+has mapping => (
+    is      => 'ro',
+    isa     => AesMapping,
+    builder => sub { Chart::GGPlot::Aes->new() }
+);
+
 has layers => (
     is      => 'ro',
     isa     => ArrayRef,
@@ -108,10 +149,6 @@ has scales => (
     is      => 'ro',
     default => sub { Chart::GGPlot::ScalesList->new() }
 );
-has mapping => (
-    is      => 'ro',
-    default => sub { Chart::GGPlot::Aes->new() }
-);
 has _theme   => ( is => 'rwp', isa => InstanceOf['Chart::GGPlot::Theme'] );
 has coordinates => (
     is      => 'rw',
@@ -162,7 +199,7 @@ method summary () {
           . sprintf( " [%sx%s] ", $self->data->nrow, $self->data->ncol ) . "\n";
     }
     if ( $self->mapping->length > 0 ) {
-        $s .= &$label("mapping:") . $self->mapping . "\n";
+        $s .= &$label("mapping:") . $self->mapping->string . "\n";
     }
     if ( $self->scales->length() > 0 ) {
         $s .=
@@ -173,6 +210,25 @@ method summary () {
     return $s;
 }
 
+
+method theme() {
+    use Chart::GGPlot::Global;
+
+    my $default = Chart::GGPlot::Global->theme_current();
+    if (my $theme = $self->_theme) {
+        if ($theme->is_complete) {
+            return $theme;
+        }
+        else {
+            return $theme->defaults($default);
+        }
+    } else {
+        return $default;
+    }
+}
+
+
+
 method add_layer ($layer) {
     push @{ $self->layers }, $layer;
 
@@ -185,11 +241,13 @@ method add_layer ($layer) {
     return $self;
 }
 
+
 method add_labels ($labels) {
     $self->_labels( $self->_labels->merge($labels) );
     return $self;
 }
 
+
 method add_scale ($scale) {
     $self->scales->add($scale);
     return $self;
@@ -218,22 +276,6 @@ classmethod make_labels($mapping) {
     return \%labels;
 }
 
-method theme() {
-    use Chart::GGPlot::Global;
-
-    my $default = Chart::GGPlot::Global->theme_current();
-    if (my $theme = $self->_theme) {
-        if ($theme->is_complete) {
-            return $theme;
-        }
-        else {
-            return $theme->defaults($default);
-        }
-    } else {
-        return $default;
-    }
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -250,34 +292,80 @@ Chart::GGPlot::Plot - ggplot class
 
 =head1 VERSION
 
-version 0.0000_01
+version 0.0000_02
 
 =head1 DESCRIPTION
 
 This class represents the ggplot class.
-Instead of this class you would usually want to look at L<Chart::GGPlot>,
+Instead of this class you would usually want to directly use L<Chart::GGPlot>,
 which is a function interface of this library and is closer to R ggplot2's API.
 
+=head1 ATTRIBUTES
+
+=head2 backend
+
+Consumer of L<Chart::GGPlot::Backend>.
+Defaults to an L<Chart::GGPlot::Backend::Plotly> object.
+
+=head2 data
+
+L<Data::Frame> object.
+
+=head2 mapping
+
+Aesthetics mapping.
+Default is an empty L<Chart::GGPlot::Aes> object.
+
 =head1 METHODS
 
 =head2 show
 
-    $ggplot->show(HashRef $opts={});
+    show(HashRef $opts={})
 
 Show the plot (like in web browser).
 Implementation depends on the plotting backend.
 
 =head2 save
 
-    $ggplot->save($filename, HashRef $opts={});
+    save($filename, HashRef $opts={})
 
 Export the plot to a static image file.
 Implementation depends on the plotting backend.
 
-=head2 summary()
+=head2 summary
+
+    summary()
 
 Get a useful description of a ggplot object.
 
+=head2 theme
+
+    theme()
+
+Returns theme of the plot.
+
+=head2 add_layer
+
+    add_layer($layer)
+
+Adds a L<Chart::GGPlot::Layer> object to the plot.
+
+You normally don't have to explicitly call this method.
+
+=head2 add_labels
+
+    add_labels($labels)
+
+Adds a L<Chart::GGPlot::Label> object to the plot.
+
+You normally don't have to explicitly call this method.
+
+=head2 add_scale
+
+    add_scale($scale)
+
+You normally don't have to explicitly call this method.
+
 =head1 SEE ALSO
 
 L<Chart::GGPlot>
@@ -288,7 +376,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Stephan Loyd.
+This software is copyright (c) 2019 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
