@@ -7,7 +7,7 @@ package Chart::GGPlot::Util::Scales;
 
 use Chart::GGPlot::Setup qw(:base :pdl);
 
-our $VERSION = '0.0000_01'; # TRIAL VERSION
+our $VERSION = '0.0000_02'; # TRIAL VERSION
 
 use Color::Brewer;
 use Convert::Color::LCh;
@@ -789,6 +789,11 @@ fun dollar ($p, :$accuracy=undef, :$scale=1,
         -decimal_point   => $decimal_mark,
         -int_curr_symbol => $prefix,
         ( $negative_parens ? ( -n_sign_posn => 0 ) : () ),
+
+        # Number::Format defaulty uses locale's P/N_SEP_BY_SPACE.
+        # Here we force these values to 0 to be align with R's scale::dollar.
+        -p_sep_by_space  => 0,
+        -n_sep_by_space  => 0,
     );
 
     no warnings 'numeric';
@@ -875,7 +880,7 @@ Chart::GGPlot::Util::Scales - R 'scales' package functions used by Chart::GGPlot
 
 =head1 VERSION
 
-version 0.0000_01
+version 0.0000_02
 
 =head1 FUNCTIONS
 
@@ -923,7 +928,7 @@ Stephan Loyd <sloyd@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Stephan Loyd.
+This software is copyright (c) 2019 by Stephan Loyd.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
